@@ -8,8 +8,10 @@ dx = function(r)
   if ("PropErrVar" %in% EstNames) wt = wt + r$Prediction^2*r$Est["PE","PropErrVar"]
   if ("ScaleErrVar" %in% EstNames) wt = r$Scale*r$Est["PE","ScaleErrVar"]
 
-  dev.new(width=12, height=6)
-  DefPar = par(mfrow=c(1,2))
+  if (attr(dev.cur(), "names") == "null device") {
+    dev.new(width=12, height=6)
+    DefPar = par(mfrow=c(1,2))
+  }
   plot(r$Prediction, r$Prediction + r$Residual, xlab="Prediction", ylab="Observation", pch=16)
   abline(a=0, b=1, lty=3)
 
@@ -21,5 +23,5 @@ dx = function(r)
     plot(r$Prediction, r$Residual, xlab="Prediction", ylab="Residual", pch=16)
     abline(h=0)
   }
-  par(DefPar)
+  if ("DefPar" %in% ls()) par(DefPar)
 }
